//JSON结构化数据显示模块
var json_view = function (option, success) {
    var object = new JsonView(option);
    success();
    return object;
}

function JsonView(option) {
    this.markControl = option.markControl;
    this.init();
    this.markControl.on('step.board.show', this, function (event, context, eventObject) {
        this.container.removeClass('span12');
        this.container.addClass('span10');
    });
    this.markControl.on('step.board.hide', this, function (event, context, eventObject) {
        this.container.removeClass('span10');
        this.container.addClass('span12');
    });
    this.markControl.on('task.get.before', this, function (event, context, eventObject) {
        this.task = undefined;
        this.render();
    });
    this.markControl.on('task.get.success', this, function (event, context, eventObject) {
        this.task = context.task;
        this.render();
    });
    this.markControl.on('task.get.none', this, function (event, context, eventObject) {
        this.task = undefined;
        this.render();
    });
}

JsonView.prototype.init = function () {
    this.container = this.markControl.container.imageContent;
    this.container.height(this.markControl.container.centerContent.height());
    this.container.css('overflow', 'scroll');

    this.holder = getDom(this.holder_dom, this.markControl).appendTo(this.container);
    this.holder.empty();
}

JsonView.prototype.render = function () {
    if (this.task != undefined && this.task.jsonData != undefined) {
        let questionNumbers = {};
        this.task.markStepList.forEach(step => {
            questionNumbers[step.questionNumber] = true;
        });

        let questions = this.task.jsonData || [];
        let paperqQuestions = this.task.paperData || [];
        for (var j in questions) {
        	var question = questions[j];
        	var paperQuestion = paperqQuestions[j];
            // 按题号过滤
            if (questionNumbers[question.mainNumber + "." + question.subNumber] === true) {
                let numberTitle = {
                    "blocks": [{
                        "type": "text",
                        "param": {"bold": true},
                        "value": "题号：" + question.mainNumber + "-" + question.subNumber
                    }]
                };
                let bodyTitle = {
                    "blocks": [{
                        "type": "text",
                        "param": {"bold": true},
                        "value": "题干："
                    }]
                };
                let answerTitle = {
                    "blocks": [{
                        "type": "text",
                        "param": {"bold": true},
                        "value": "考生答案："
                    }, {
                        "type": "text",
                        "param": {
                            "italic": true,
                            "danger": true
                        },
                        "value": "(字数统计：" + this.textCount(question.studentAnswer) + ")"
                    }]
                };
                let standardTitle = {
                    "blocks": [{
                        "type": "text",
                        "param": {"bold": true},
                        "value": "标准答案："
                    }]
                };
                $(renderSection(numberTitle)).appendTo(this.holder);
                $(renderSection(bodyTitle)).appendTo(this.holder);
                if(question.parentBody!=null && question.parentBody!=undefined){
					$(renderRichText(question.parentBody)).appendTo(this.holder); 
				}
                $(renderRichText(question.body)).appendTo(this.holder);
                $(renderSection(answerTitle)).appendTo(this.holder);
                $(renderRichText(question.studentAnswer)).appendTo(this.holder);
                $(renderSection(standardTitle)).appendTo(this.holder);
                $(renderRichText(question.answer)).appendTo(this.holder);
            }
        }
        if (this.viewer != undefined) {
            this.viewer.destroy();
        }
        this.viewer = new Viewer(this.container[0], {});
        this.markControl.trigger('task.load.finish');
    } else {
        this.holder.empty();
    }
}

JsonView.prototype.textCount = function (jsonBody) {
    let sections = jsonBody.sections || [];
    let count = 0;
    sections.forEach(section => {
        let blocks = section.blocks || [];
        blocks.forEach(block => {
            if (block.type === 'text' && block.value != undefined) {
                count += block.value.length;
            }
        });
    });
    return count;
}

JsonView.prototype.holder_dom = '<div class="rich-text"></div>';